==> jscad__amf-deserializer-2.2.1.jar: META-INF/resources/webjars/jscad__amf-deserializer/2.2.1/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.2.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.2.0...@jscad/amf-deserializer@2.2.1) (2021-10-04)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.2.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.1.3...@jscad/amf-deserializer@2.2.0) (2021-09-27)


### Features

* **amf-deserializer:** reworked to use saxes library ([8e89118](https://github.com/jscad/OpenJSCAD.org/commit/8e89118337499575da5613d8aaf86b78241ccfe9))





## [2.1.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.1.2...@jscad/amf-deserializer@2.1.3) (2021-09-09)


### Bug Fixes

* **web:** added open issues and discord community to help ([4ea1196](https://github.com/jscad/OpenJSCAD.org/commit/4ea11966af4b3ecbb5c1a3d53b7ac90c4cd349b1))





## [2.1.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.1.1...@jscad/amf-deserializer@2.1.2) (2021-06-20)

**Note:** Version bump only for package @jscad/amf-deserializer





## [2.1.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.1.0...@jscad/amf-deserializer@2.1.1) (2021-06-11)


### Bug Fixes

* **amf-deserializer:** corrected conversion of color specifications found on object elements ([f1eca2b](https://github.com/jscad/OpenJSCAD.org/commit/f1eca2b1401e5b12289f85c94e144d3c220949da))





# [2.1.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.2...@jscad/amf-deserializer@2.1.0) (2021-06-01)


### Features

* **modeling:** rework math objects to conform with gl-matrix ([#804](https://github.com/jscad/OpenJSCAD.org/issues/804)) ([2e52f10](https://github.com/jscad/OpenJSCAD.org/commit/2e52f104e569f2bb7dd9e1be3d238f471f4d3dfa))





## [2.0.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.0...@jscad/amf-deserializer@2.0.2) (2021-04-20)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





## [2.0.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.0...@jscad/amf-deserializer@2.0.1) (2021-04-15)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





# [2.0.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.11...@jscad/amf-deserializer@2.0.0) (2021-04-12)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.11](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.10...@jscad/amf-deserializer@2.0.0-alpha.11) (2021-03-07)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.9...@jscad/amf-deserializer@2.0.0-alpha.10) (2021-02-07)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.8...@jscad/amf-deserializer@2.0.0-alpha.9) (2021-01-02)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.7...@jscad/amf-deserializer@2.0.0-alpha.8) (2020-12-04)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.6...@jscad/amf-deserializer@2.0.0-alpha.7) (2020-11-07)


### Bug Fixes

* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





# [2.0.0-alpha.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.5...@jscad/amf-deserializer@2.0.0-alpha.6) (2020-10-11)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))





# [2.0.0-alpha.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.4...@jscad/amf-deserializer@2.0.0-alpha.5) (2020-09-29)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.3...@jscad/amf-deserializer@2.0.0-alpha.4) (2020-09-28)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.2...@jscad/amf-deserializer@2.0.0-alpha.3) (2020-09-19)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.1...@jscad/amf-deserializer@2.0.0-alpha.2) (2020-09-08)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.0...@jscad/amf-deserializer@2.0.0-alpha.1) (2020-08-19)

**Note:** Version bump only for package @jscad/amf-deserializer





# 2.0.0-alpha.0 (2020-08-13)


### Bug Fixes

* **amf-deserializer:** correct translate() & metadata  ([#495](https://github.com/jscad/OpenJSCAD.org/issues/495)) ([726bc8e](https://github.com/jscad/OpenJSCAD.org/commit/726bc8e338ce9746859050daa7af798daa0e5a13))
* **colors:** colorize is now immutable & returns new geometries ([#566](https://github.com/jscad/OpenJSCAD.org/issues/566)) ([916824c](https://github.com/jscad/OpenJSCAD.org/commit/916824c63a0bf8896d1b6f85a82b129a013bec58))





### Features

* **amf-deserializer:** overhaul for V2 (#467)
* **io:** change api to deserialize(options, source)

<a name="0.2.3"></a>
## [0.2.3](https://github.com/jscad/io/compare/@jscad/amf-deserializer@0.2.2...@jscad/amf-deserializer@0.2.3) (2018-11-25)




**Note:** Version bump only for package @jscad/amf-deserializer

<a name="0.2.2"></a>
## [0.2.2](https://github.com/jscad/io/compare/@jscad/amf-deserializer@0.2.1...@jscad/amf-deserializer@0.2.2) (2018-11-22)




**Note:** Version bump only for package @jscad/amf-deserializer

<a name="0.2.1"></a>
## [0.2.1](https://github.com/jscad/io/compare/@jscad/amf-deserializer@0.2.0...@jscad/amf-deserializer@0.2.1) (2017-12-14)




**Note:** Version bump only for package @jscad/amf-deserializer

<a name="0.2.0"></a>
# [0.2.0](https://github.com/jscad/io/compare/@jscad/amf-deserializer@0.1.0...@jscad/amf-deserializer@0.2.0) (2017-11-29)


### Features

* add support for a status callback for de/serialization progress ([#49](https://github.com/jscad/io/issues/49)) ([f457cdb](https://github.com/jscad/io/commit/f457cdb))




<a name="0.1.0"></a>
# [0.1.0](https://github.com/jscad/io/compare/@jscad/amf-deserializer@0.0.4...@jscad/amf-deserializer@0.1.0) (2017-11-14)


### Features

* **deserializers:** added csg output capabilities to amf & obj deserializers & basic tests ([#47](https://github.com/jscad/io/issues/47)) ([abf3040](https://github.com/jscad/io/commit/abf3040))




<a name="0.0.4"></a>
## [0.0.4](https://github.com/jscad/io/compare/@jscad/amf-deserializer@0.0.3...@jscad/amf-deserializer@0.0.4) (2017-11-04)




**Note:** Version bump only for package @jscad/amf-deserializer

<a name="0.0.3"></a>
## [0.0.3](https://github.com/jscad/io/compare/@jscad/amf-deserializer@0.0.2...@jscad/amf-deserializer@0.0.3) (2017-10-10)




**Note:** Version bump only for package @jscad/amf-deserializer

<a name="0.0.2"></a>
## 0.0.2 (2017-10-10)




**Note:** Version bump only for package @jscad/amf-deserializer

==> jscad__amf-deserializer-2.2.2.jar: META-INF/resources/webjars/jscad__amf-deserializer/2.2.2/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [2.2.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.2.1...@jscad/amf-deserializer@2.2.2) (2021-10-17)

**Note:** Version bump only for package @jscad/amf-deserializer





## [2.2.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.2.0...@jscad/amf-deserializer@2.2.1) (2021-10-04)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.2.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.1.3...@jscad/amf-deserializer@2.2.0) (2021-09-27)


### Features

* **amf-deserializer:** reworked to use saxes library ([8e89118](https://github.com/jscad/OpenJSCAD.org/commit/8e89118337499575da5613d8aaf86b78241ccfe9))





## [2.1.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.1.2...@jscad/amf-deserializer@2.1.3) (2021-09-09)


### Bug Fixes

* **web:** added open issues and discord community to help ([4ea1196](https://github.com/jscad/OpenJSCAD.org/commit/4ea11966af4b3ecbb5c1a3d53b7ac90c4cd349b1))





## [2.1.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.1.1...@jscad/amf-deserializer@2.1.2) (2021-06-20)

**Note:** Version bump only for package @jscad/amf-deserializer





## [2.1.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.1.0...@jscad/amf-deserializer@2.1.1) (2021-06-11)


### Bug Fixes

* **amf-deserializer:** corrected conversion of color specifications found on object elements ([f1eca2b](https://github.com/jscad/OpenJSCAD.org/commit/f1eca2b1401e5b12289f85c94e144d3c220949da))





# [2.1.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.2...@jscad/amf-deserializer@2.1.0) (2021-06-01)


### Features

* **modeling:** rework math objects to conform with gl-matrix ([#804](https://github.com/jscad/OpenJSCAD.org/issues/804)) ([2e52f10](https://github.com/jscad/OpenJSCAD.org/commit/2e52f104e569f2bb7dd9e1be3d238f471f4d3dfa))





## [2.0.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.0...@jscad/amf-deserializer@2.0.2) (2021-04-20)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





## [2.0.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.0...@jscad/amf-deserializer@2.0.1) (2021-04-15)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))
* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





# [2.0.0](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.11...@jscad/amf-deserializer@2.0.0) (2021-04-12)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.11](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.10...@jscad/amf-deserializer@2.0.0-alpha.11) (2021-03-07)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.10](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.9...@jscad/amf-deserializer@2.0.0-alpha.10) (2021-02-07)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.9](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.8...@jscad/amf-deserializer@2.0.0-alpha.9) (2021-01-02)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.8](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.7...@jscad/amf-deserializer@2.0.0-alpha.8) (2020-12-04)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.7](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.6...@jscad/amf-deserializer@2.0.0-alpha.7) (2020-11-07)


### Bug Fixes

* **io:** io revisited ([#714](https://github.com/jscad/OpenJSCAD.org/issues/714)) ([22f04f1](https://github.com/jscad/OpenJSCAD.org/commit/22f04f1b2894a82e24952655875e73b74727bf86))





# [2.0.0-alpha.6](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.5...@jscad/amf-deserializer@2.0.0-alpha.6) (2020-10-11)


### Bug Fixes

* **all:** V2 : several fixes for modeling ([#705](https://github.com/jscad/OpenJSCAD.org/issues/705)) ([62017a4](https://github.com/jscad/OpenJSCAD.org/commit/62017a41214169d6e000f1e0c11aaefdd68e1097))





# [2.0.0-alpha.5](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.4...@jscad/amf-deserializer@2.0.0-alpha.5) (2020-09-29)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.4](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.3...@jscad/amf-deserializer@2.0.0-alpha.4) (2020-09-28)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.3](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.2...@jscad/amf-deserializer@2.0.0-alpha.3) (2020-09-19)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.2](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.1...@jscad/amf-deserializer@2.0.0-alpha.2) (2020-09-08)

**Note:** Version bump only for package @jscad/amf-deserializer





# [2.0.0-alpha.1](https://github.com/jscad/OpenJSCAD.org/compare/@jscad/amf-deserializer@2.0.0-alpha.0...@jscad/amf-deserializer@2.0.0-alpha.1) (2020-08-19)

**Note:** Version bump only for package @jscad/amf-deserializer





# 2.0.0-alpha.0 (2020-08-13)


### Bug Fixes

* **amf-deserializer:** correct translate() & metadata  ([#495](https://github.com/jscad/OpenJSCAD.org/issues/495)) ([726bc8e](https://github.com/jscad/OpenJSCAD.org/commit/726bc8e338ce9746859050daa7af798daa0e5a13))
* **colors:** colorize is now immutable & returns new geometries ([#566](https://github.com/jscad/OpenJSCAD.org/issues/566)) ([916824c](https://github.com/jscad/OpenJSCAD.org/commit/916824c63a0bf8896d1b6f85a82b129a013bec58))





### Features

* **amf-deserializer:** overhaul for V2 (#467)
* **io:** change api to deserialize(options, source)

<a name="0.2.3"></a>
## [0.2.3](https://github.com/jscad/io/compare/@jscad/amf-deserializer@0.2.2...@jscad/amf-deserializer@0.2.3) (2018-11-25)




**Note:** Version bump only for package @jscad/amf-deserializer

<a name="0.2.2"></a>
## [0.2.2](https://github.com/jscad/io/compare/@jscad/amf-deserializer@0.2.1...@jscad/amf-deserializer@0.2.2) (2018-11-22)




**Note:** Version bump only for package @jscad/amf-deserializer

<a name="0.2.1"></a>
## [0.2.1](https://github.com/jscad/io/compare/@jscad/amf-deserializer@0.2.0...@jscad/amf-deserializer@0.2.1) (2017-12-14)




**Note:** Version bump only for package @jscad/amf-deserializer

<a name="0.2.0"></a>
# [0.2.0](https://github.com/jscad/io/compare/@jscad/amf-deserializer@0.1.0...@jscad/amf-deserializer@0.2.0) (2017-11-29)


### Features

* add support for a status callback for de/serialization progress ([#49](https://github.com/jscad/io/issues/49)) ([f457cdb](https://github.com/jscad/io/commit/f457cdb))




<a name="0.1.0"></a>
# [0.1.0](https://github.com/jscad/io/compare/@jscad/amf-deserializer@0.0.4...@jscad/amf-deserializer@0.1.0) (2017-11-14)


### Features

* **deserializers:** added csg output capabilities to amf & obj deserializers & basic tests ([#47](https://github.com/jscad/io/issues/47)) ([abf3040](https://github.com/jscad/io/commit/abf3040))




<a name="0.0.4"></a>
## [0.0.4](https://github.com/jscad/io/compare/@jscad/amf-deserializer@0.0.3...@jscad/amf-deserializer@0.0.4) (2017-11-04)




**Note:** Version bump only for package @jscad/amf-deserializer

<a name="0.0.3"></a>
## [0.0.3](https://github.com/jscad/io/compare/@jscad/amf-deserializer@0.0.2...@jscad/amf-deserializer@0.0.3) (2017-10-10)




**Note:** Version bump only for package @jscad/amf-deserializer

<a name="0.0.2"></a>
## 0.0.2 (2017-10-10)




**Note:** Version bump only for package @jscad/amf-deserializer
